@@ -16,7 +16,6 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
-#include <QDesktopWidget>
 #include <QInputDialog>
 #include <QLoggingCategory>
 #include <QPointer>
@@ -237,8 +236,9 @@ static void parsePrompt(const QString &prompt, QString &identifier, bool &ignore
 
 int main(int argc, char **argv)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain("ksshaskpass");
 
@@ -282,8 +282,7 @@ int main(int argc, char **argv)
     }
 
     // Open KWallet to see if an item was previously stored
-    WId winId = QApplication::desktop()->winId();
-    std::unique_ptr<KWallet::Wallet> wallet(ignoreWallet ? nullptr : KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), winId));
+    std::unique_ptr<KWallet::Wallet> wallet(ignoreWallet ? nullptr : KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), 0));
 
     if ((!ignoreWallet) && (!identifier.isNull()) && wallet.get() && wallet->hasFolder(walletFolder)) {
         wallet->setFolder(walletFolder);
